@@ -1,7 +1,7 @@
 /*
  * version - determine the version of calc
  *
- * Copyright (C) 2023  David I. Bell and Landon Curt Noll
+ * Copyright (C) 1989-2025  David I. Bell and Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -62,9 +62,22 @@
  *      bug fix and improvement updates will cause MINOR_PATCH to increment.
  */
 #define MAJOR_VER       2       /* level 1: major library version */
-#define MINOR_VER       15      /* level 2: minor library version */
-#define MAJOR_PATCH     1       /* level 3: major software version level */
-#define MINOR_PATCH     0       /* level 4: minor software version level */
+#define MINOR_VER       16      /* level 2: minor library version */
+#define MAJOR_PATCH     0       /* level 3: major software version level */
+#define MINOR_PATCH     2       /* level 4: minor software version level */
 
+/*
+ * Defining PERMIT_DANGEROUS_ADDRESS_ARITHMETIC is NOT supported!
+ *
+ * If someone were to be a foolish as to permit dangerous address arithmetic, then we
+ * negate the major version to further "disavow" such a calc compile.
+ */
+#if defined(PERMIT_DANGEROUS_ADDRESS_ARITHMETIC)
+#  undef TEMP_MAJOR_VER
+#  define TEMP_MAJOR_VER MAJOR_VER
+#  undef MAJOR_VER
+#  define MAJOR_VER (-TEMP_MAJOR_VER)
+#  undef TEMP_MAJOR_VER
+#endif
 
 #endif /* !INCLUDE_VERSION_H*/
